/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   TrackingChainConfig.h
/// \date   18.02.2024
/// \brief  A configuration reader for the TrackingChain class
/// \author Sergei Zharko <s.zharko@gsi.de>

#pragma once

#include "yaml/Property.h"

#include <string>
#include <tuple>

namespace cbm::algo
{
  /// \struct TrackingChainConfig
  /// \brief Configuration reader for the TrackingChain class
  struct TrackingChainConfig {
    std::string fsParName;      ///< Tracking parameter file name
    std::string fsMoniOutName;  ///< Monitor output file name
    int fNofThreads;            ///< Number of threads for tracking
    bool fbStoreMonitor;        ///< Stores monitor snapshot

    CBM_YAML_PROPERTIES(
                      yaml::Property(&TrackingChainConfig::fsParName, "ParName", "CA parameters input"),
                      yaml::Property(&TrackingChainConfig::fsMoniOutName, "MoniOutName", "Monitor output"),
                      yaml::Property(&TrackingChainConfig::fNofThreads, "NofThreads", "Number of threads"),
                      yaml::Property(&TrackingChainConfig::fbStoreMonitor, "StoreMonitor", "If store monitor"));
  };
}  // namespace cbm::algo
